Data & I/O
==========

Data formats
------------
- CSV/Parquet tables with multi-index (period, scenario, stage)
- YAML/JSON for settings and metadata

Loaders
-------
.. autofunction:: vy4e_optmodel.data.load_case

Writers
-------
.. automodule:: vy4e_optmodel.results
    :members:
